'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var common = require('@nestjs/common');
var iterare = require('iterare');
var tslib = require('tslib');

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

class ValidationPipe extends common.ValidationPipe {
  flattenValidationErrors(validationErrors) {
    return iterare.iterate(validationErrors).map(error => this.mapChildrenToValidationErrors(error)).flatten().filter(item => !!item.constraints).map(item => ({
      errors: Object.values(item.constraints || {}),
      field: item.field || item.property
    })).filter(errorObject => errorObject.errors.length > 0).flatten().toArray();
  }

  prependConstraintsWithParentProp(parentPath, error) {
    return _extends({
      field: parentPath + "." + error.property
    }, super.prependConstraintsWithParentProp(parentPath, error));
  }

}

exports.GraphqlValidationFilter = class GraphqlValidationFilter {
  catch(exception, host) {
    if (host.getType() === 'graphql') {
      // const gqlHost = GqlArgumentsHost.create(host);
      var response = exception.getResponse();

      if (Array.isArray(response.message) && Array.isArray(response.message[0].errors) && typeof response.message[0].field === 'string') {
        return {
          userErrors: response.message.map(error => ({
            field: error.field.split('.'),
            message: error.errors[0]
          }))
        };
      }
    }

    return exception;
  }

};
exports.GraphqlValidationFilter = /*#__PURE__*/tslib.__decorate([/*#__PURE__*/common.Catch(common.BadRequestException)], exports.GraphqlValidationFilter);

exports.ValidationPipe = ValidationPipe;
//# sourceMappingURL=nestjs-better-validation.cjs.development.js.map
